@@ -10,9 +10,9 @@ class ExtendedExecutionResult:
     def __init__(
         self,
         response: str,
-        errors: Optional[Dict[str, Any]],
-        data: Optional[Dict[str, Any]],
-        extensions: Optional[Dict[str, Any]],
+        errors: Optional[Dict[str, Any]] = None,
+        data: Optional[Dict[str, Any]] = None,
+        extensions: Optional[Dict[str, Any]] = None,
     ) -> None:
         self.response: str = response
         self.errors: Dict[str, Any] = errors if errors is not None else {}
